@@ -4,13 +4,12 @@
 """Test that the examples run correctly."""
 
 from hdfs import Config
-from imp import load_source
-from nose.plugins.skip import SkipTest
+from hdfs.config import _load_source
 from six import add_metaclass
-from util import _IntegrationTest
+from test.util import _IntegrationTest
 import os
 import os.path as osp
-
+import pytest
 
 class _ExamplesType(type):
 
@@ -26,10 +25,10 @@ class _ExamplesType(type):
 
       def test(self):
         try:
-          load_source(module, fpath)
+          _load_source(module, fpath)
         except ImportError:
           # Unmet dependency.
-          raise SkipTest
+          pytest.skip()
 
       test.__name__ = 'test_{}'.format(module)
       test.__doc__ = 'Test for example {}.'.format(fpath)
